simulate antibody kinetics of y over a time interval
simresp.tinf(
lambda,
t_end,
age_fixed,
antigen_isos,
n_mcmc_samples = 0,
renew_params,
predpar,
...
)a list with:
t = times (in days, birth at day 0),
b = bacteria level, for each antibody signal (not used; probably meaningless),
y = antibody level, for each antibody signal
smp = whether an infection involves a big jump or a small jump
t.inf = times when infections have occurred.
seroconversion rate (1/days),
end of time interval (beginning is time 0) in days(?)
parameter estimates for fixed age (age_fixed in years) or not. when age_fixed = NA then age at infection is used.
antigen isotypes
a posterior sample may be selected (1:4000), or not when n_mcmc_samples = 0 a posterior sample is chosen at random.
At infection,
a new parameter sample may be generated
(when renew_params = TRUE).
Otherwise (when renew_params = FALSE),
a sample is generated at birth and kept,
but baseline y0 are carried over from prior infections.
an array() with dimensions named:
antigen_iso
parameter
obs
Arguments passed on to ldpar, ab, mk_baseline
ageage at infection
nmcmcmc sample to use
nparnumber of parameters
t
parnumeric matrix of model parameters:
rows are parameters
columns are biomarkers
kabinteger indicating which row to read from blims
nnumber of observations
blimsrange of possible baseline antibody levels